==> alfresco-remote-api-16.36-sources.jar: org/alfresco/rest/api/model/Client.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2017 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.rest.api.model;

/**
 * Representation of a client app.
 *
 * @author Jamal Kaabi-Mofrad
 * @since 5.2.1
 */
public class Client
{
    /**
     * client app name. Used to lookup the client
     * that is registered to send emails so that
     * client's specific configuration could be used.
     */
    protected String client;

    public String getClient()
    {
        return client;
    }

    public Client setClient(String client)
    {
        this.client = client;
        return this;
    }

    @Override
    public String toString()
    {
        return "Client [ client=" + client + ']';
    }
}

==> alfresco-remote-api-25.3.0.61-sources.jar: org/alfresco/rest/api/model/Client.java <==
/*
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2017 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.rest.api.model;

/**
 * Representation of a client app.
 *
 * @author Jamal Kaabi-Mofrad
 * @since 5.2.1
 */
public class Client
{
    /**
     * client app name. Used to lookup the client that is registered to send emails so that client's specific configuration could be used.
     */
    protected String client;

    public String getClient()
    {
        return client;
    }

    public Client setClient(String client)
    {
        this.client = client;
        return this;
    }

    @Override
    public String toString()
    {
        return "Client [ client=" + client + ']';
    }
}
